Package: demoShiny
Title: Runs a 'Shiny' App as Demo or Lists All Demo 'Shiny' Apps
Version: 0.1
Authors@R: 
  person("Sigbert", "Klinke", email="sigbert@hu-berlin.de", role=c("aut", "cre"))
Description: Mimics the demo functionality for 'Shiny' apps in a package. Apps stored to the package subdirectory inst/shiny can be called by demoShiny(topic).
Depends: shiny
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.0.2
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2020-01-13 11:58:23 UTC; sigbert
Author: Sigbert Klinke [aut, cre]
Maintainer: Sigbert Klinke <sigbert@hu-berlin.de>
Repository: CRAN
Date/Publication: 2020-01-16 10:30:07 UTC
Built: R 4.6.0; ; 2026-04-28 16:32:12 UTC; unix
